@@ -44,6 +44,7 @@ class Server(BaseDomain):
     :param private_net: List[:class:`PrivateNet <hcloud.servers.domain.PrivateNet`]
             Private networks information.
     """
+
     STATUS_RUNNING = "running"
     """Server Status running"""
     STATUS_INIT = "initializing"
@@ -82,31 +83,33 @@ class Server(BaseDomain):
         "volumes",
         "private_net",
         "created",
-        "primary_disk_size"
+        "primary_disk_size",
+        "placement_group",
     )
 
     def __init__(
-            self,
-            id,
-            name=None,
-            status=None,
-            created=None,
-            public_net=None,
-            server_type=None,
-            datacenter=None,
-            image=None,
-            iso=None,
-            rescue_enabled=None,
-            locked=None,
-            backup_window=None,
-            outgoing_traffic=None,
-            ingoing_traffic=None,
-            included_traffic=None,
-            protection=None,
-            labels=None,
-            volumes=None,
-            private_net=None,
-            primary_disk_size=None,
+        self,
+        id,
+        name=None,
+        status=None,
+        created=None,
+        public_net=None,
+        server_type=None,
+        datacenter=None,
+        image=None,
+        iso=None,
+        rescue_enabled=None,
+        locked=None,
+        backup_window=None,
+        outgoing_traffic=None,
+        ingoing_traffic=None,
+        included_traffic=None,
+        protection=None,
+        labels=None,
+        volumes=None,
+        private_net=None,
+        primary_disk_size=None,
+        placement_group=None,
     ):
         self.id = id
         self.name = name
@@ -128,6 +131,7 @@ class Server(BaseDomain):
         self.volumes = volumes
         self.private_net = private_net
         self.primary_disk_size = primary_disk_size
+        self.placement_group = placement_group
 
 
 class CreateServerResponse(BaseDomain):
@@ -142,19 +146,15 @@ class CreateServerResponse(BaseDomain):
     :param root_password: str, None
            The root password of the server if no SSH-Key was given on server creation
     """
-    __slots__ = (
-        "server",
-        "action",
-        "next_actions",
-        "root_password"
-    )
+
+    __slots__ = ("server", "action", "next_actions", "root_password")
 
     def __init__(
-            self,
-            server,  # type: BoundServer
-            action,  # type: BoundAction
-            next_actions,  # type: List[Action]
-            root_password  # type: str
+        self,
+        server,  # type: BoundServer
+        action,  # type: BoundAction
+        next_actions,  # type: List[Action]
+        root_password,  # type: str
     ):
         self.server = server
         self.action = action
@@ -170,15 +170,13 @@ class ResetPasswordResponse(BaseDomain):
     :param root_password: str
            The root password of the server
     """
-    __slots__ = (
-        "action",
-        "root_password"
-    )
+
+    __slots__ = ("action", "root_password")
 
     def __init__(
-            self,
-            action,  # type: BoundAction
-            root_password  # type: str
+        self,
+        action,  # type: BoundAction
+        root_password,  # type: str
     ):
         self.action = action
         self.root_password = root_password
@@ -192,15 +190,13 @@ class EnableRescueResponse(BaseDomain):
     :param root_password: str
            The root password of the server in the rescue mode
     """
-    __slots__ = (
-        "action",
-        "root_password"
-    )
+
+    __slots__ = ("action", "root_password")
 
     def __init__(
-            self,
-            action,  # type: BoundAction
-            root_password  # type: str
+        self,
+        action,  # type: BoundAction
+        root_password,  # type: str
     ):
         self.action = action
         self.root_password = root_password
@@ -216,17 +212,14 @@ class RequestConsoleResponse(BaseDomain):
     :param password: str
            VNC password to use for this connection. This password only works in combination with a wss_url with valid token.
     """
-    __slots__ = (
-        "action",
-        "wss_url",
-        "password"
-    )
+
+    __slots__ = ("action", "wss_url", "password")
 
     def __init__(
-            self,
-            action,  # type: BoundAction
-            wss_url,  # type: str
-            password,  # type: str
+        self,
+        action,  # type: BoundAction
+        wss_url,  # type: str
+        password,  # type: str
     ):
         self.action = action
         self.wss_url = wss_url
@@ -239,25 +232,35 @@ class PublicNetwork(BaseDomain):
     :param ipv4: :class:`IPv4Address <hcloud.servers.domain.IPv4Address>`
     :param ipv6: :class:`IPv6Network <hcloud.servers.domain.IPv6Network>`
     :param floating_ips: List[:class:`BoundFloatingIP <hcloud.floating_ips.client.BoundFloatingIP>`]
+    :param primary_ipv4: :class:`BoundPrimaryIP <hcloud.primary_ips.domain.BoundPrimaryIP>`
+    :param primary_ipv6: :class:`BoundPrimaryIP <hcloud.primary_ips.domain.BoundPrimaryIP>`
     :param firewalls: List[:class:`PublicNetworkFirewall <hcloud.servers.client.PublicNetworkFirewall>`]
     """
+
     __slots__ = (
         "ipv4",
         "ipv6",
         "floating_ips",
-        "firewalls"
+        "firewalls",
+        "primary_ipv4",
+        "primary_ipv6",
     )
 
-    def __init__(self,
-                 ipv4,  # type: IPv4Address
-                 ipv6,  # type: IPv6Network
-                 floating_ips,  # type: List[BoundFloatingIP]
-                 firewalls=None,  # type: List[PublicNetworkFirewall]
-                 ):
+    def __init__(
+        self,
+        ipv4,  # type: IPv4Address
+        ipv6,  # type: IPv6Network
+        floating_ips,  # type: List[BoundFloatingIP]
+        primary_ipv4,  # type: BoundPrimaryIP
+        primary_ipv6,  # type: BoundPrimaryIP
+        firewalls=None,  # type: List[PublicNetworkFirewall]
+    ):
         self.ipv4 = ipv4
         self.ipv6 = ipv6
         self.floating_ips = floating_ips
         self.firewalls = firewalls
+        self.primary_ipv4 = primary_ipv4
+        self.primary_ipv6 = primary_ipv6
 
 
 class PublicNetworkFirewall(BaseDomain):
@@ -266,20 +269,19 @@ class PublicNetworkFirewall(BaseDomain):
     :param firewall: :class:`BoundFirewall <hcloud.firewalls.domain.BoundFirewall>`
     :param status: str
     """
-    __slots__ = (
-        "firewall",
-        "status"
-    )
+
+    __slots__ = ("firewall", "status")
 
     STATUS_APPLIED = "applied"
     """Public Network Firewall Status applied"""
     STATUS_PENDING = "pending"
     """Public Network Firewall Status pending"""
 
-    def __init__(self,
-                 firewall,  # type: BoundFirewall
-                 status,  # type: str
-                 ):
+    def __init__(
+        self,
+        firewall,  # type: BoundFirewall
+        status,  # type: str
+    ):
         self.firewall = firewall
         self.status = status
 
@@ -294,17 +296,15 @@ class IPv4Address(BaseDomain):
     :param dns_ptr: str
            DNS PTR for the ip
     """
-    __slots__ = (
-        "ip",
-        "blocked",
-        "dns_ptr"
-    )
 
-    def __init__(self,
-                 ip,  # type: str
-                 blocked,  # type: bool
-                 dns_ptr,  # type: str
-                 ):
+    __slots__ = ("ip", "blocked", "dns_ptr")
+
+    def __init__(
+        self,
+        ip,  # type: str
+        blocked,  # type: bool
+        dns_ptr,  # type: str
+    ):
         self.ip = ip
         self.blocked = blocked
         self.dns_ptr = dns_ptr
@@ -324,19 +324,15 @@ class IPv6Network(BaseDomain):
     :param network_mask: str
            The network mask
     """
-    __slots__ = (
-        "ip",
-        "blocked",
-        "dns_ptr",
-        "network",
-        "network_mask"
-    )
 
-    def __init__(self,
-                 ip,  # type: str
-                 blocked,  # type: bool
-                 dns_ptr,  # type: list
-                 ):
+    __slots__ = ("ip", "blocked", "dns_ptr", "network", "network_mask")
+
+    def __init__(
+        self,
+        ip,  # type: str
+        blocked,  # type: bool
+        dns_ptr,  # type: list
+    ):
         self.ip = ip
         self.blocked = blocked
         self.dns_ptr = dns_ptr
@@ -357,20 +353,41 @@ class PrivateNet(BaseDomain):
     :param mac_address: str
            The mac address of the interface on the server
     """
-    __slots__ = (
-        "network",
-        "ip",
-        "alias_ips",
-        "mac_address"
-    )
 
-    def __init__(self,
-                 network,  # type: BoundNetwork
-                 ip,  # type: str
-                 alias_ips,  # type: List[str]
-                 mac_address,  # type: str
-                 ):
+    __slots__ = ("network", "ip", "alias_ips", "mac_address")
+
+    def __init__(
+        self,
+        network,  # type: BoundNetwork
+        ip,  # type: str
+        alias_ips,  # type: List[str]
+        mac_address,  # type: str
+    ):
         self.network = network
         self.ip = ip
         self.alias_ips = alias_ips
         self.mac_address = mac_address
+
+
+class ServerCreatePublicNetwork(BaseDomain):
+    """Server Create Public Network Domain
+
+    :param ipv4: Optional[:class:`PrimaryIP <hcloud.primary_ips.domain.PrimaryIP>`]
+    :param ipv6: Optional[:class:`PrimaryIP <hcloud.primary_ips.domain.PrimaryIP>`]
+    :param enable_ipv4: bool
+    :param enable_ipv6: bool
+    """
+
+    __slots__ = ("ipv4", "ipv6", "enable_ipv4", "enable_ipv6")
+
+    def __init__(
+        self,
+        ipv4=None,  # type: hcloud.primary_ips.domain.PrimaryIP
+        ipv6=None,  # type: hcloud.primary_ips.domain.PrimaryIP
+        enable_ipv4=True,  # type: bool
+        enable_ipv6=True,  # type: bool
+    ):
+        self.ipv4 = ipv4
+        self.ipv6 = ipv6
+        self.enable_ipv4 = enable_ipv4
+        self.enable_ipv6 = enable_ipv6
