@@ -13,12 +13,15 @@ class BoundVolume(BoundModelBase):
     def __init__(self, client, data, complete=True):
         location = data.get("location")
         if location is not None:
-            data['location'] = BoundLocation(client._client.locations, location)
+            data["location"] = BoundLocation(client._client.locations, location)
 
         from hcloud.servers.client import BoundServer
+
         server = data.get("server")
         if server is not None:
-            data['server'] = BoundServer(client._client.servers, {"id": server}, complete=False)
+            data["server"] = BoundServer(
+                client._client.servers, {"id": server}, complete=False
+            )
         super(BoundVolume, self).__init__(client, data, complete)
 
     def get_actions_list(self, status=None, sort=None, page=None, per_page=None):
@@ -51,7 +54,7 @@ class BoundVolume(BoundModelBase):
 
     def update(self, name=None, labels=None):
         # type: (Optional[str], Optional[Dict[str, str]]) -> BoundAction
-        """ Updates the volume properties.
+        """Updates the volume properties.
 
         :param name: str (optional)
                New volume name
@@ -109,7 +112,7 @@ class BoundVolume(BoundModelBase):
 
 
 class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
-    results_list_attribute_name = 'volumes'
+    results_list_attribute_name = "volumes"
 
     def get_by_id(self, id):
         # type: (int) -> volumes.client.BoundVolume
@@ -118,10 +121,14 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
         :param id: int
         :return: :class:`BoundVolume <hcloud.volumes.client.BoundVolume>`
         """
-        response = self._client.request(url="/volumes/{volume_id}".format(volume_id=id), method="GET")
-        return BoundVolume(self, response['volume'])
+        response = self._client.request(
+            url="/volumes/{volume_id}".format(volume_id=id), method="GET"
+        )
+        return BoundVolume(self, response["volume"])
 
-    def get_list(self, name=None, label_selector=None, page=None, per_page=None, status=None):
+    def get_list(
+        self, name=None, label_selector=None, page=None, per_page=None, status=None
+    ):
         # type: (Optional[str], Optional[str], Optional[int], Optional[int], Optional[List[str]]) -> PageResults[List[BoundVolume], Meta]
         """Get a list of volumes from this account
 
@@ -139,18 +146,20 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
         """
         params = {}
         if name is not None:
-            params['name'] = name
+            params["name"] = name
         if label_selector is not None:
-            params['label_selector'] = label_selector
+            params["label_selector"] = label_selector
         if status is not None:
             params["status"] = status
         if page is not None:
-            params['page'] = page
+            params["page"] = page
         if per_page is not None:
-            params['per_page'] = per_page
+            params["per_page"] = per_page
 
         response = self._client.request(url="/volumes", method="GET", params=params)
-        volumes = [BoundVolume(self, volume_data) for volume_data in response['volumes']]
+        volumes = [
+            BoundVolume(self, volume_data) for volume_data in response["volumes"]
+        ]
         return self._add_meta_to_result(volumes, response)
 
     def get_all(self, label_selector=None, status=None):
@@ -163,7 +172,9 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
                Can be used to filter volumes by their status. The response will only contain volumes matching the status.
         :return: List[:class:`BoundVolume <hcloud.volumes.client.BoundVolume>`]
         """
-        return super(VolumesClient, self).get_all(label_selector=label_selector, status=status)
+        return super(VolumesClient, self).get_all(
+            label_selector=label_selector, status=status
+        )
 
     def get_by_name(self, name):
         # type: (str) -> BoundVolume
@@ -175,15 +186,16 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
         """
         return super(VolumesClient, self).get_by_name(name)
 
-    def create(self,
-               size,  # type: int
-               name,  # type: str
-               labels=None,  # type: Optional[str]
-               location=None,  # type: Optional[Location]
-               server=None,  # type: Optional[Server],
-               automount=None,  # type: Optional[bool],
-               format=None,  # type: Optional[str],
-               ):
+    def create(
+        self,
+        size,  # type: int
+        name,  # type: str
+        labels=None,  # type: Optional[str]
+        location=None,  # type: Optional[Location]
+        server=None,  # type: Optional[Server],
+        automount=None,  # type: Optional[bool],
+        format=None,  # type: Optional[str],
+    ):
         # type: (...) -> CreateVolumeResponse
         """Creates a new volume attached to a server.
 
@@ -208,32 +220,34 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
         if not (bool(location) ^ bool(server)):
             raise ValueError("only one of server or location must be provided")
 
-        data = {
-            'name': name,
-            'size': size,
-        }
+        data = {"name": name, "size": size}
         if labels is not None:
-            data['labels'] = labels
+            data["labels"] = labels
         if location is not None:
-            data['location'] = location.id_or_name
+            data["location"] = location.id_or_name
 
         if server is not None:
-            data['server'] = server.id
+            data["server"] = server.id
         if automount is not None:
-            data['automount'] = automount
+            data["automount"] = automount
         if format is not None:
-            data['format'] = format
+            data["format"] = format
 
         response = self._client.request(url="/volumes", json=data, method="POST")
 
         result = CreateVolumeResponse(
-            volume=BoundVolume(self, response['volume']),
-            action=BoundAction(self._client.actions, response['action']),
-            next_actions=[BoundAction(self._client.actions, action) for action in response['next_actions']]
+            volume=BoundVolume(self, response["volume"]),
+            action=BoundAction(self._client.actions, response["action"]),
+            next_actions=[
+                BoundAction(self._client.actions, action)
+                for action in response["next_actions"]
+            ],
         )
         return result
 
-    def get_actions_list(self, volume, status=None, sort=None, page=None, per_page=None):
+    def get_actions_list(
+        self, volume, status=None, sort=None, page=None, per_page=None
+    ):
         # type: (Volume, Optional[List[str]], Optional[int], Optional[int]) -> PageResults[List[BoundAction], Meta]
         """Returns all action objects for a volume.
 
@@ -258,10 +272,16 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
         if per_page is not None:
             params["per_page"] = per_page
 
-        response = self._client.request(url="/volumes/{volume_id}/actions".format(volume_id=volume.id), method="GET",
-                                        params=params)
-        actions = [BoundAction(self._client.actions, action_data) for action_data in response['actions']]
-        return add_meta_to_result(actions, response, 'actions')
+        response = self._client.request(
+            url="/volumes/{volume_id}/actions".format(volume_id=volume.id),
+            method="GET",
+            params=params,
+        )
+        actions = [
+            BoundAction(self._client.actions, action_data)
+            for action_data in response["actions"]
+        ]
+        return add_meta_to_result(actions, response, "actions")
 
     def get_actions(self, volume, status=None, sort=None):
         # type: (Union[Volume, BoundVolume], Optional[List[str]]) -> List[BoundAction]
@@ -278,7 +298,7 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
 
     def update(self, volume, name=None, labels=None):
         # type:(Union[Volume, BoundVolume],  Optional[str],  Optional[Dict[str, str]]) -> BoundVolume
-        """ Updates the volume properties.
+        """Updates the volume properties.
 
         :param volume: :class:`BoundVolume <hcloud.volumes.client.BoundVolume>` or :class:`Volume <hcloud.volumes.domain.Volume>`
         :param name: str (optional)
@@ -292,8 +312,12 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
             data.update({"name": name})
         if labels is not None:
             data.update({"labels": labels})
-        response = self._client.request(url="/volumes/{volume_id}".format(volume_id=volume.id), method="PUT", json=data)
-        return BoundVolume(self, response['volume'])
+        response = self._client.request(
+            url="/volumes/{volume_id}".format(volume_id=volume.id),
+            method="PUT",
+            json=data,
+        )
+        return BoundVolume(self, response["volume"])
 
     def delete(self, volume):
         # type: (Union[Volume, BoundVolume]) -> BoundAction
@@ -302,7 +326,9 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
         :param volume: :class:`BoundVolume <hcloud.volumes.client.BoundVolume>` or :class:`Volume <hcloud.volumes.domain.Volume>`
         :return: boolean
         """
-        self._client.request(url="/volumes/{volume_id}".format(volume_id=volume.id), method="DELETE")
+        self._client.request(
+            url="/volumes/{volume_id}".format(volume_id=volume.id), method="DELETE"
+        )
         return True
 
     def resize(self, volume, size):
@@ -314,9 +340,12 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
                New volume size in GB (must be greater than current size)
         :return: :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        data = self._client.request(url="/volumes/{volume_id}/actions/resize".format(volume_id=volume.id),
-                                    json={'size': size}, method="POST")
-        return BoundAction(self._client.actions, data['action'])
+        data = self._client.request(
+            url="/volumes/{volume_id}/actions/resize".format(volume_id=volume.id),
+            json={"size": size},
+            method="POST",
+        )
+        return BoundAction(self._client.actions, data["action"])
 
     def attach(self, volume, server, automount=None):
         # type: (Union[Volume, BoundVolume], Union[Server, BoundServer], Optional[bool]) -> BoundAction
@@ -327,13 +356,16 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
         :param automount: boolean
         :return: :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        data = {'server': server.id}
+        data = {"server": server.id}
         if automount is not None:
             data["automount"] = automount
 
-        data = self._client.request(url="/volumes/{volume_id}/actions/attach".format(volume_id=volume.id), json=data,
-                                    method="POST")
-        return BoundAction(self._client.actions, data['action'])
+        data = self._client.request(
+            url="/volumes/{volume_id}/actions/attach".format(volume_id=volume.id),
+            json=data,
+            method="POST",
+        )
+        return BoundAction(self._client.actions, data["action"])
 
     def detach(self, volume):
         # type: (Union[Volume, BoundVolume]) -> BoundAction
@@ -342,9 +374,11 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
         :param volume: :class:`BoundVolume <hcloud.volumes.client.BoundVolume>` or :class:`Volume <hcloud.volumes.domain.Volume>`
         :return: :class:`BoundAction <hcloud.actions.client.BoundAction>`
         """
-        data = self._client.request(url="/volumes/{volume_id}/actions/detach".format(volume_id=volume.id),
-                                    method="POST")
-        return BoundAction(self._client.actions, data['action'])
+        data = self._client.request(
+            url="/volumes/{volume_id}/actions/detach".format(volume_id=volume.id),
+            method="POST",
+        )
+        return BoundAction(self._client.actions, data["action"])
 
     def change_protection(self, volume, delete=None):
         # type: (Union[Volume, BoundVolume], Optional[bool], Optional[bool]) -> BoundAction
@@ -360,6 +394,10 @@ class VolumesClient(ClientEntityBase, GetEntityByNameMixin):
             data.update({"delete": delete})
 
         response = self._client.request(
-            url="/volumes/{volume_id}/actions/change_protection".format(volume_id=volume.id),
-            method="POST", json=data)
-        return BoundAction(self._client.actions, response['action'])
+            url="/volumes/{volume_id}/actions/change_protection".format(
+                volume_id=volume.id
+            ),
+            method="POST",
+            json=data,
+        )
+        return BoundAction(self._client.actions, response["action"])
